@@ -1,5 +1,5 @@
 # __init__.py
 from .vms import *
-from .icon import ICONDATA
+from .icon import Icon
 # Version of the realpython-reader package
-__version__ = "0.1.8"
+__version__ = "0.1.9"
